@@ -16,15 +16,15 @@ EOF
 my $border = Tickit::Widget::Border->new(
    h_border => 10,
    v_border => 2,
-   child => my $vbox = Tickit::Widget::VBox->new( spacing => 2, bg => "black" ),
-);
+)
+   ->set_child( my $vbox = Tickit::Widget::VBox->new( spacing => 2, style => { bg => "black" } ) );
 
 my @buttons;
 foreach my $colour (qw( red blue green yellow )) {
    $vbox->add(
       my $button = Tickit::Widget::Button->new(
          label => $colour,
-         on_click => sub { $border->pen->chattr( bg => $colour ) },
+         on_click => sub { $border->set_style( bg => $colour ) },
       )
    );
    push @buttons, $button;
