@@ -16,7 +16,8 @@ my $vbox = Tickit::Widget::VBox->new(
 foreach ( 1 .. 6 ) {
    $vbox->add(
       Tickit::Widget::Static->new(
-         text => "Row $_", bg => $_, fg => "hi-white",
+         text => "Row $_",
+         style => { bg => $_, fg => "hi-white" },
          align => "centre", valign => "middle",
       ),
       expand => 1,
