@@ -1,17 +1,16 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2020 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2022 -- leonerd@leonerd.org.uk
 
-use Object::Pad 0.27;
+use Object::Pad 0.70 ':experimental(adjust_params)';
 
-package Tickit::Style;
+package Tickit::Style 0.54;
 
 use strict;
 use warnings;
 use 5.010;
-
-our $VERSION = '0.51';
+use experimental 'postderef';
 
 use Carp;
 
@@ -237,7 +236,7 @@ sub import
 
       foreach my $hash ( \%RESHAPE_KEYS, \%RESHAPE_TEXTWIDTH_KEYS, \%REDRAW_KEYS ) {
          # shallow copy is sufficient
-         $hash->{$type} = { %{ $hash->{$srctype} } } if $hash->{$srctype};
+         $hash->{$type} = { $hash->{$srctype}->%* } if $hash->{$srctype};
       }
    }
 
@@ -321,7 +320,7 @@ sub style_reshape_keys
 sub _reshape_keys
 {
    my ( $type ) = @_;
-   return keys %{ $RESHAPE_KEYS{$type} };
+   return keys $RESHAPE_KEYS{$type}->%*;
 }
 
 =head2 style_reshape_textwidth_keys
@@ -345,7 +344,7 @@ sub style_reshape_textwidth_keys
 sub _reshape_textwidth_keys
 {
    my ( $type ) = @_;
-   return keys %{ $RESHAPE_TEXTWIDTH_KEYS{$type} };
+   return keys $RESHAPE_TEXTWIDTH_KEYS{$type}->%*;
 }
 
 =head2 style_redraw_keys
@@ -372,7 +371,7 @@ sub style_redraw_keys
 sub _redraw_keys
 {
    my ( $type ) = @_;
-   return keys %{ $REDRAW_KEYS{$type} };
+   return keys $REDRAW_KEYS{$type}->%*;
 }
 
 my @ON_STYLE_LOAD;
@@ -476,24 +475,31 @@ sub on_style_load
 }
 
 class # hide from indexer
-   Tickit::Style::_Tagset;
+   Tickit::Style::_Keyset :strict(params) {
 
-use Struct::Dumb;
+   # A "Keyset" is the set of style keys applied to one particular set of
+   # style tags
+   field $tags  :reader :param;
+   field $style :reader :param;
 
-# A "Keyset" is the set of style keys applied to one particular set of style
-# tags
-struct Keyset => [qw( tags style )];
-
-has @_keysets;
-
-BUILD
-{
-   @_keysets = @_;
+   method clone
+   {
+      return __PACKAGE__->new( tags => $tags, style => { %$style } );
+   }
 }
 
+class # hide from indexer
+   Tickit::Style::_Tagset :strict(params);
+
+use experimental 'postderef';
+
+field @_keysets;
+
+ADJUST :params ( :$keysets = undef ) { @_keysets = $keysets->@* if $keysets; }
+
 method clone
 {
-   return __PACKAGE__->new( map { Keyset( $_->tags, { %{$_->style} } ) } @_keysets );
+   return __PACKAGE__->new( keysets => [ map { $_->clone } @_keysets ] );
 }
 
 method add
@@ -519,13 +525,13 @@ method merge_with_tags
 {
    my ( $tags, $style ) = @_;
 
-   my $keyset = Keyset( $tags, $style );
+   my $keyset = Tickit::Style::_Keyset->new( tags => $tags, style => $style );
    @_keysets = ( $keyset ) and return if !@_keysets;
 
    # First see if we have to merge an existing one
    KEYSET: foreach my $keyset ( @_keysets ) {
       $keyset->tags->{$_} or next KEYSET for keys %$tags;
-      $tags->{$_} or next KEYSET for keys %{ $keyset->tags };
+      $tags->{$_} or next KEYSET for keys $keyset->tags->%*;
 
       # Merge
       foreach my $key ( keys %$style ) {
@@ -537,7 +543,7 @@ method merge_with_tags
 
    # Keep sorted, most tags first
    # TODO: this might be doable more efficiently but we don't care for now
-   @_keysets = sort { scalar keys %{ $b->tags } <=> scalar keys %{ $a->tags } } ( @_keysets, $keyset );
+   @_keysets = sort { scalar keys $b->tags->%* <=> scalar keys $a->tags->%* } ( @_keysets, $keyset );
 }
 
 method keysets
