@@ -1,13 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2011-2020 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2011-2022 -- leonerd@leonerd.org.uk
 
-use Object::Pad 0.27;
+use Object::Pad 0.73 ':experimental(adjust_params init_expr)';
 
-package Tickit::Widget::Border 0.31;
+package Tickit::Widget::Border 0.36;
 class Tickit::Widget::Border
-   extends Tickit::SingleChildWidget;
+   :strict(params)
+   :isa(Tickit::SingleChildWidget);
 
 use Tickit::Style;
 
@@ -60,15 +61,13 @@ without the C<set_> prefix.
 
 =cut
 
-has $_top_border    = 0;
-has $_bottom_border = 0;
-has $_left_border   = 0;
-has $_right_border  = 0;
+field $_top_border    :reader = 0;
+field $_bottom_border :reader = 0;
+field $_left_border   :reader = 0;
+field $_right_border  :reader = 0;
 
-BUILD
+ADJUST :params ( %params )
 {
-   my %params = @_;
-
    defined $params{$_} and $self->${\"set_$_"}( delete $params{$_} ) for qw(
       border
       h_border v_border
@@ -108,11 +107,11 @@ Return or set the number of lines of border at the top of the widget
 
 =cut
 
-method top_border { $_top_border }
+# generated accessor
 
 method set_top_border
 {
-   $_top_border = $_[0];
+   ( $_top_border ) = @_;
    $self->resized;
 }
 
@@ -128,11 +127,11 @@ Return or set the number of lines of border at the bottom of the widget
 
 =cut
 
-method bottom_border { $_bottom_border }
+# generated accessor
 
 method set_bottom_border
 {
-   $_bottom_border = $_[0];
+   ( $_bottom_border ) = @_;
    $self->resized;
 }
 
@@ -148,11 +147,11 @@ Return or set the number of cols of border at the left of the widget
 
 =cut
 
-method left_border { $_left_border }
+# generated accessor
 
 method set_left_border
 {
-   $_left_border = $_[0];
+   ( $_left_border ) = @_;
    $self->resized;
 }
 
@@ -168,11 +167,11 @@ Return or set the number of cols of border at the right of the widget
 
 =cut
 
-method right_border { $_right_border }
+# generated accessor
 
 method set_right_border
 {
-   $_right_border = $_[0];
+   ( $_right_border ) = @_;
    $self->resized;
 }
 
@@ -186,7 +185,8 @@ Set the number of cols of both horizontal (left and right) borders simultaneousl
 
 method set_h_border
 {
-   $_left_border = $_right_border = $_[0];
+   my ( $border ) = @_;
+   $_left_border = $_right_border = $border;
    $self->resized;
 }
 
@@ -200,7 +200,8 @@ Set the number of lines of both vertical (top and bottom) borders simultaneously
 
 method set_v_border
 {
-   $_top_border = $_bottom_border = $_[0];
+   my ( $border ) = @_;
+   $_top_border = $_bottom_border = $border;
    $self->resized;
 }
 
@@ -214,12 +215,13 @@ Set the number of cols or lines in all four borders simultaneously
 
 method set_border
 {
-   $_top_border = $_bottom_border = $_left_border = $_right_border = $_[0];
+   my ( $border ) = @_;
+   $_top_border = $_bottom_border = $_left_border = $_right_border = $border;
    $self->resized;
 }
 
 ## This should come from Tickit::ContainerWidget
-method children_changed { $self->reshape }
+method children_changed { $self->resized }
 
 method reshape
 {
