@@ -1,14 +1,15 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2021 -- leonerd@leonerd.org.uk
 #  Original render code by Tom Molesworth
 
-use Object::Pad 0.27;
+use Object::Pad 0.73 ':experimental(init_expr)';
 
-package Tickit::Widget::Placegrid 0.31;
+package Tickit::Widget::Placegrid 0.36;
 class Tickit::Widget::Placegrid
-   extends Tickit::Widget;
+   :strict(params)
+   :isa(Tickit::Widget);
 
 use Tickit::Style;
 use Tickit::RenderBuffer qw( LINE_SINGLE LINE_THICK );
@@ -69,14 +70,7 @@ dimensions in the centre of the grid.
 
 =cut
 
-has $_title;
-
-BUILD
-{
-   my %params = @_;
-
-   $_title = $params{title};
-}
+field $_title :param = undef;
 
 method lines { 1 }
 method cols  { 1 }
