@@ -1,14 +1,17 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2021 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2022 -- leonerd@leonerd.org.uk
 
-use Object::Pad 0.57;
+use Object::Pad 0.73 ':experimental(init_expr)';
 
-package Tickit::Widget::RadioButton 0.34;
+package Tickit::Widget::RadioButton 0.36;
 class Tickit::Widget::RadioButton
+   :strict(params)
    :isa(Tickit::Widget);
 
+use Object::Pad qw( :experimental(init_expr) );
+
 use Tickit::Style;
 
 use Carp;
@@ -150,10 +153,10 @@ is passed to the group's C<on_changed> callback.
 
 =cut
 
-has $_label     :reader         :param;
-has $_on_toggle :reader :writer :param = undef;
-has $_value     :reader :writer :param = undef;
-has $_group     :reader         :param { Tickit::Widget::RadioButton::Group->new };
+field $_label     :reader         :param;
+field $_on_toggle :reader :writer :param = undef;
+field $_value     :reader :writer :param = undef;
+field $_group     :reader         :param = Tickit::Widget::RadioButton::Group->new;
 
 method lines
 {
@@ -197,7 +200,7 @@ Returns or sets the label text of the button.
 
 method set_label
 {
-   $_label = $_[0];
+   ( $_label ) = @_;
    $self->reshape;
    $self->redraw;
 }
@@ -345,8 +348,8 @@ Returns a new group.
 
 =cut
 
-   has $_active :reader;
-   has $_on_changed :reader :writer;
+   field $_active :reader;
+   field $_on_changed :reader :writer;
 
 =head2 active
 
